import { Issuer } from "openid-client";
/**
 * NOTE: We can add auto discovery of the provider's endpoint
 * that requires only one endpoint to be specified by the user.
 * Check out `Issuer.discover`
 *
 * Client supporting OAuth 2.x and OIDC
 * @param {import("types/internals").InternalOptions} options
 */
export async function openidClient(options) {
    var _a, _b, _c;
    /** @type {import("types/providers").OAuthConfig} */
    const provider = options.provider;
    let issuer;
    if (provider.wellKnown) {
        issuer = await Issuer.discover(provider.wellKnown);
    }
    else {
        issuer = new Issuer({
            issuer: provider.issuer,
            authorization_endpoint: (_a = provider.authorization.url) !== null && _a !== void 0 ? _a : provider.authorization,
            token_endpoint: (_b = provider.token.url) !== null && _b !== void 0 ? _b : provider.token,
            userinfo_endpoint: (_c = provider.userinfo.url) !== null && _c !== void 0 ? _c : provider.userinfo,
        });
    }
    const client = new issuer.Client({
        client_id: provider.clientId,
        client_secret: provider.clientSecret,
        redirect_uris: [provider.callbackUrl],
    });
    return client;
}
