import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
/**
 * Renders an error page.
 * @param {{
 *   baseUrl: string
 *   basePath: string
 *   error?: string
 *   res: import("types/internals").NextAuthResponse
 * }} params
 */
export default function error({ baseUrl, basePath, error = 'default', res }) {
    var _a;
    const signinPageUrl = `${baseUrl}${basePath}/signin`;
    const errors = {
        default: {
            statusCode: 200,
            heading: 'Error',
            message: _jsx("p", { children: _jsx("a", Object.assign({ className: 'site', href: baseUrl }, { children: baseUrl.replace(/^https?:\/\//, '') }), void 0) }, void 0)
        },
        configuration: {
            statusCode: 500,
            heading: 'Server error',
            message: (_jsxs("div", { children: [_jsx("p", { children: "There is a problem with the server configuration." }, void 0), _jsx("p", { children: "Check the server logs for more information." }, void 0)] }, void 0))
        },
        accessdenied: {
            statusCode: 403,
            heading: 'Access Denied',
            message: (_jsxs("div", { children: [_jsx("p", { children: "You do not have permission to sign in." }, void 0), _jsx("p", { children: _jsx("a", Object.assign({ className: 'button', href: signinPageUrl }, { children: "Sign in" }), void 0) }, void 0)] }, void 0))
        },
        verification: {
            statusCode: 403,
            heading: 'Unable to sign in',
            message: (_jsxs("div", { children: [_jsx("p", { children: "The sign in link is no longer valid." }, void 0), _jsx("p", { children: "It may have been used already or it may have expired." }, void 0)] }, void 0)),
            signin: _jsx("p", { children: _jsx("a", Object.assign({ className: 'button', href: signinPageUrl }, { children: "Sign in" }), void 0) }, void 0)
        }
    };
    const { statusCode, heading, message, signin } = (_a = errors[error.toLowerCase()]) !== null && _a !== void 0 ? _a : errors.default;
    res.status(statusCode);
    return (_jsxs("div", Object.assign({ className: 'error' }, { children: [_jsx("h1", { children: heading }, void 0), _jsx("div", Object.assign({ className: 'message' }, { children: message }), void 0), signin] }), void 0));
}
