export function upperSnake(s: any): any;
export function capitalize(s: any): string;
/**
 * Wraps an object of methods and adds error handling.
 * @param {import("types").EventCallbacks} methods
 * @param {import("types").LoggerInstance} logger
 * @return {import("types").EventCallbacks}
 */
export function eventsErrorHandler(methods: import("types").EventCallbacks, logger: import("types").LoggerInstance): import("types").EventCallbacks;
/**
 * Handles adapter induced errors.
 * @param {import("types/adapters").Adapter} [adapter]
 * @param {import("types").LoggerInstance} logger
 * @return {import("types/adapters").Adapter}
 */
export function adapterErrorHandler(adapter?: import("types/adapters").Adapter | undefined, logger: import("types").LoggerInstance): import("types/adapters").Adapter;
/**
 * Same as the default `Error`, but it is JSON serializable.
 * @source https://iaincollins.medium.com/error-handling-in-javascript-a6172ccdf9af
 */
export class UnknownError extends Error {
    constructor(error: any);
    toJSON(): {
        name: string;
        message: string;
        stack: string | undefined;
    };
}
export class OAuthCallbackError extends UnknownError {
}
/**
 * Thrown when an Email address is already associated with an account
 * but the user is trying an OAuth account that is not linked to it.
 */
export class AccountNotLinkedError extends UnknownError {
}
